==> qtsensors-opensource-src-5.2.0.tar.xz: qtsensors-opensource-src-5.2.0/src/plugins/sensors/sensorfw/sensorfwmagnetometer.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SENSORFWMAGNETOMETER_H
#define SENSORFWMAGNETOMETER_H

#include "sensorfwsensorbase.h"
#include <QtSensors/qmagnetometer.h>

#include <magnetometersensor_i.h>
#include <datatypes/magneticfield.h>



class SensorfwMagnetometer : public SensorfwSensorBase
{
    Q_OBJECT

public:
    static char const * const id;
    SensorfwMagnetometer(QSensor *sensor);
protected:
    virtual bool doConnect();
    virtual void start();
    virtual QString sensorName() const;
    virtual qreal correctionFactor() const;
    virtual void init() Q_DECL_OVERRIDE;

private:
    static const float NANO;
    QMagnetometerReading m_reading;
    bool m_initDone;
    bool m_isGeoMagnetometer;

private slots:
    void slotDataAvailable(const MagneticField& data);
    void slotFrameAvailable(const QVector<MagneticField>&);

};

#endif

==> qtsensors-opensource-src-5.3.1.tar.xz: qtsensors-opensource-src-5.3.1/src/plugins/sensors/sensorfw/sensorfwmagnetometer.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SENSORFWMAGNETOMETER_H
#define SENSORFWMAGNETOMETER_H

#include "sensorfwsensorbase.h"
#include <QtSensors/qmagnetometer.h>

#include <magnetometersensor_i.h>
#include <datatypes/magneticfield.h>



class SensorfwMagnetometer : public SensorfwSensorBase
{
    Q_OBJECT

public:
    static char const * const id;
    SensorfwMagnetometer(QSensor *sensor);
protected:
    bool doConnect() Q_DECL_OVERRIDE;
    void start() Q_DECL_OVERRIDE;
    QString sensorName() const Q_DECL_OVERRIDE;
    qreal correctionFactor() const Q_DECL_OVERRIDE;
    virtual void init();

private:
    static const float NANO;
    QMagnetometerReading m_reading;
    bool m_initDone;
    bool m_isGeoMagnetometer;

private slots:
    void slotDataAvailable(const MagneticField& data);
    void slotFrameAvailable(const QVector<MagneticField>&);

};

#endif
